@@ -7,14 +7,13 @@ from pygments.formatters import TerminalFormatter
 from inspect import signature
 from json import loads, dumps
 from subprocess import Popen
-from os.path import join as path_join, expanduser, abspath, isdir, basename
+from os.path import join as path_join, expanduser, abspath, isdir, basename, exists
 from os import mkdir, rename
 import cloudinary
 import re
 from pkg_resources import resource_filename
 from shutil import copy
 
-
 TEMPLATE_FOLDER = "templates"
 
 TEMPLATE_EXTS = {
@@ -26,19 +25,32 @@ TEMPLATE_EXTS = {
     "java": "java",
 }
 
+CLOUDINARY_CLI_CONFIG_FILE = abspath(path_join(expanduser("~"), '.cloudinary-cli-config'))
+
+if not exists(CLOUDINARY_CLI_CONFIG_FILE):
+    open(CLOUDINARY_CLI_CONFIG_FILE, "a").close()
+
 CUSTOM_TEMPLATE_FOLDER = abspath(path_join(expanduser("~"), '.cld-cli-templates'))
 
+if not isdir(CUSTOM_TEMPLATE_FOLDER):
+    mkdir(CUSTOM_TEMPLATE_FOLDER)
+
 F_FAIL = lambda x: "\033[91m" + x + "\033[0m"
 F_WARN = lambda x: "\033[93m" + x + "\033[0m"
 F_OK = lambda x: "\033[92m" + x + "\033[0m"
 
+write_out = lambda contents, filename: open(filename, "w+").write(dumps(contents, indent=2))
+
 def get_sample(which, transformation):
     cloudinary._config.cloud_name="demo"
     res = utils.cloudinary_url(which, raw_transformation=transformation)[0]
     return res
 
+
+not_callable = ['is_appengine_sandbox', 'call_tags_api', 'call_context_api', 'call_cacheable_api', 'call_api', 'text']
+
 def get_help(api):
-    funcs = list(filter(lambda x: callable(api.__dict__[x]) and x[0].islower(), api.__dict__.keys()))
+    funcs = list(filter(lambda x: callable(api.__dict__[x]) and x[0].islower() and x not in not_callable, api.__dict__.keys()))
     sigs = '\n'.join(["{0:25}({1})".format(x, ", ".join(list(signature(api.__dict__[x]).parameters))) for x in funcs])
     return sigs
 
@@ -76,6 +88,3 @@ def parse_args_kwargs(func, params):
     args = [parse_option_value(x) for x in params[:l]]
     kwargs = {k: parse_option_value(v) for k, v in [x.split('=') for x in params[l:]]} if params[l:] else {}
     return args, kwargs
-
-def open_url(url):
-    Popen(["open", url])
